Authors
==========
This package is being developed and maintained by `Rabindra Khadka <https://iamrabin.github.io/>`_.



DREAMS was written in collaboration with `AI LAB, Oslo Metropolitean University <https://www.oslomet.no/en/about/tkd/it/ai-lab>`_ and `AI Mind project <https://www.ai-mind.eu/project/>`_.

Lead Development Team
---------------------

- Rabindra Khadka (`rabindra.khadka@ymail.com <rabindra.khadka@ymail.com>`_)
- Pedro G. Lind (`pedrolin@oslomet.no <pedrolin@oslomet.no>`_)
- Anis Yazidi (`anisy@oslomet.no <anisy@oslomet.no>`_)


Contributors
------------
- Asma Belhadi (`asbel9617@oslomet.no <asbel9617@oslomet.no>`_)



Citing DREAMS_MC
-----------------
To be announced.